XKB Considerations
================================================================================

> If you want custom keymaps on your machine, switch to Wayland (and/or fix any
> remaining issues preventing you from doing so) instead of hoping this will
> ever work on X.

— [Peter Hutterer](https://who-t.blogspot.com/2020/09/no-user-specific-xkb-configuration-in-x.html)



Resources
--------------------------------------------------------------------------------

XKB is a tricky piece of software.
The following resources might be helpful if you want to dig in:

- https://www.charvolant.org/doug/xkb/html/
- https://wiki.archlinux.org/title/X_keyboard_extension
- https://wiki.archlinux.org/title/Xorg/Keyboard_configuration
- https://github.com/xkbcommon/libxkbcommon/blob/master/doc/keymap-format-text-v1.md
